#
# spec file for package rootlesskit
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         rootless-containers
%global repo            rootlesskit
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           rootlesskit
Version:        1.1.1
Release:        150600.1.48
Summary:        Linux-native fakeroot using user namespaces
License:        Apache-2.0
URL:            https://github.com/rootless-containers/rootlesskit
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.18
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
RootlessKit is a Linux-native implementation of "fake root"
using user_namespaces. RootlessKit is intended to run Docker and
Kubernetes as an unprivileged user (known as "Rootless mode"), so as to protect
the real root on the host from potential container-breakout attacks.

%prep
%setup -qa1

%build
go build -mod=vendor -buildmode=pie -o _output/rootlesskit %{provider_prefix}/cmd/rootlesskit
go build -mod=vendor -buildmode=pie -o _output/rootlessctl %{provider_prefix}/cmd/rootlessctl
go build -mod=vendor -buildmode=pie -o _output/rootlesskit-docker-proxy %{provider_prefix}/cmd/rootlesskit-docker-proxy

%install
mkdir -p %{buildroot}%{_bindir}/
install -m 0755 _output/rootlesskit %{buildroot}%{_bindir}/rootlesskit
install -m 0755 _output/rootlessctl %{buildroot}%{_bindir}/rootlessctl
install -m 0755 _output/rootlesskit-docker-proxy %{buildroot}%{_bindir}/rootlesskit-docker-proxy

%files
%license LICENSE
%doc README.md docs/*.md
%{_bindir}/rootlesskit
%{_bindir}/rootlessctl
%{_bindir}/rootlesskit-docker-proxy

%changelog
* Tue Jun 20 2023 danish.prakash@suse.com
- Update to version 1.1.1:
  * v1.1.1
  * Bump up deps
  * Build(deps): Bump github.com/urfave/cli/v2 from 2.25.4 to 2.25.5
  * Build(deps): Bump github.com/urfave/cli/v2 from 2.25.3 to 2.25.4
  * Remove duplicate id ranges returned by getsubu/gid for username/uid
  * Build(deps): Bump github.com/sirupsen/logrus from 1.9.1 to 1.9.2
  * Build(deps): Bump github.com/sirupsen/logrus from 1.9.0 to 1.9.1
  * Build(deps): Bump golang.org/x/sys from 0.7.0 to 0.8.0
  * Build(deps): Bump github.com/urfave/cli/v2 from 2.25.1 to 2.25.3
  * Build(deps): Bump golang.org/x/sys from 0.6.0 to 0.7.0
  * Build(deps): Bump github.com/urfave/cli/v2 from 2.25.0 to 2.25.1
  * Build(deps): Bump golang.org/x/sys from 0.5.0 to 0.6.0
  * Build(deps): Bump github.com/urfave/cli/v2 from 2.24.4 to 2.25.0
  * Build(deps): Bump golang.org/x/net from 0.1.0 to 0.7.0
  * Build(deps): Bump github.com/urfave/cli/v2 from 2.24.3 to 2.24.4
  * CI: update Docker to v23.0.0
  * Build(deps): Bump golang.org/x/sys from 0.4.0 to 0.5.0
  * Build(deps): Bump github.com/urfave/cli/v2 from 2.24.2 to 2.24.3
  * Build(deps): Bump github.com/urfave/cli/v2 from 2.24.1 to 2.24.2
  * Build(deps): Bump github.com/urfave/cli/v2 from 2.23.7 to 2.24.1
  * CI: update Docker to v23.0.0-rc.1
  * Bump github.com/urfave/cli/v2 from 2.23.6 to 2.23.7
  * Bump golang.org/x/sys from 0.3.0 to 0.4.0
  * Bump github.com/urfave/cli/v2 from 2.23.5 to 2.23.6
  * Bump golang.org/x/sys from 0.2.0 to 0.3.0
  * v1.1.0+dev
- Add package to SLE for docker-rootless (jsc#PED-5840)
* Sun Feb  5 2023 tamuratak.9876@gmail.com
- Install rootlesskit-docker-proxy
* Sat Dec 24 2022 andrea.manzini@suse.com
- Update to version 1.1.0:
  * Support using /usr/bin/getsubids (`--subid-source=dynamic`)
    Useful for SSSD environments (subid: sss in /etc/nsswitch.conf)
    Full changes: https://github.com/rootless-containers/rootlesskit/milestone/3?closed=1
- bump vendor dependencies
* Fri Apr 22 2022 rpm@fthiessen.de
- Update to version 1.0.0:
  * use Go 1.18
  * updated some dependencies
* Tue Nov 23 2021 rbrown@suse.com
- Initial Packaging
